==> SIPDIBGE_0.1.8.tgz: SIPDIBGE/NEWS.md <==
# SIPDIBGE
## Versão 0.1.8 do Pacote SIPDIBGE - Padronização das Funções dos Pacotes

Foram realizados ajustes nas funções dos pacotes desenvolvidos para a leitura dos microdados das pesquisas do Sistema Integrado de Pesquisas Domiciliares (SIPD) do IBGE com o intuito de padronizar os procedimentos realizados, sendo recomendável a atualização dos pacotes para a versão mais recente.

## Versão 0.1.7 do Pacote SIPDIBGE - Arquivamento do Pacote POFIBGE

O pacote POFIBGE foi arquivado pela impossibilidade de reestruturação do servidor da pesquisa de referência não sendo possível a padronização em relação aos pacotes das demais pesquisas do Sistema Integrado de Pesquisas Domiciliares (SIPD) do IBGE.

[Pacote Arquivado da Pesquisa POF](https://cran.r-project.org/package=POFIBGE)

## Versão 0.1.6 do Pacote SIPDIBGE - Manuais em Português dos Pacotes

[Manual do Pacote COVIDIBGE](https://rpubs.com/gabriel-assuncao-ibge/covid)

[Manual do Pacote PNADcIBGE](https://rpubs.com/gabriel-assuncao-ibge/pnadc)

[Manual do Pacote PNSIBGE](https://rpubs.com/gabriel-assuncao-ibge/pns)

## Versão 0.1.5 do Pacote SIPDIBGE - Relatórios de Referência dos Pacotes

[GitHub de Referência](https://github.com/Gabriel-Assuncao)

## Versões 0.1.0 à 0.1.4 do Pacote SIPDIBGE - Pacotes das Pesquisas do SIPD

[Pacote da Pesquisa PNADC](https://cran.r-project.org/package=PNADcIBGE)

[Pacote da Pesquisa PNAD COVID19](https://cran.r-project.org/package=COVIDIBGE)

[Pacote da Pesquisa PNS](https://cran.r-project.org/package=PNSIBGE)

[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/SIPDIBGE)](https://cran.r-project.org/package=SIPDIBGE) [![CRAN monthly downloads](https://cranlogs.r-pkg.org/badges/SIPDIBGE "CRAN monthly downloads")](https://cran.r-project.org/package=SIPDIBGE)

==> SIPDIBGE_0.2.0.tgz: SIPDIBGE/NEWS.md <==
# SIPDIBGE
## Versão 0.2.0 do Pacote SIPDIBGE - Inserção de Argumento para Download de Arquivos

Foi inserido nas funções dos pacotes desenvolvidos para a leitura dos microdados das pesquisas do Sistema Integrado de Pesquisas Domiciliares (SIPD) do IBGE um argumento de indicação para não realizar novamente o download, caso os arquivos relacionados já existam no diretório de referência. Além disso, também foi realizada a pré-submissão do pacote PNDSIBGE que ainda está em desenvolvimento.

[Pacote em Desenvolvimento da Pesquisa PNDS](https://cran.r-project.org/package=PNDSIBGE)

[Manual do Pacote em Desenvolvimento PNDSIBGE](https://rpubs.com/gabriel-assuncao-ibge/pnds)

## Versões 0.1.8 e 0.1.9 do Pacote SIPDIBGE - Padronização das Funções dos Pacotes

Foram realizados ajustes nas funções dos pacotes desenvolvidos para a leitura dos microdados das pesquisas do Sistema Integrado de Pesquisas Domiciliares (SIPD) do IBGE com o intuito de padronizar os procedimentos realizados, sendo recomendável a atualização dos pacotes para a versão mais recente.

## Versão 0.1.7 do Pacote SIPDIBGE - Arquivamento do Pacote POFIBGE

O pacote POFIBGE foi arquivado pela impossibilidade de reestruturação do servidor da pesquisa de referência não sendo possível a padronização em relação aos pacotes das demais pesquisas do Sistema Integrado de Pesquisas Domiciliares (SIPD) do IBGE.

[Pacote Arquivado da Pesquisa POF](https://cran.r-project.org/package=POFIBGE)

[Manual do Pacote Arquivado POFIBGE](https://rpubs.com/gabriel-assuncao-ibge/pof)

## Versão 0.1.6 do Pacote SIPDIBGE - Manuais em Português dos Pacotes

[Manual do Pacote COVIDIBGE](https://rpubs.com/gabriel-assuncao-ibge/covid)

[Manual do Pacote PNADcIBGE](https://rpubs.com/gabriel-assuncao-ibge/pnadc)

[Manual do Pacote PNSIBGE](https://rpubs.com/gabriel-assuncao-ibge/pns)

## Versão 0.1.5 do Pacote SIPDIBGE - Relatórios de Referência dos Pacotes

[GitHub de Referência](https://github.com/Gabriel-Assuncao)

## Versões 0.1.0 à 0.1.4 do Pacote SIPDIBGE - Pacotes das Pesquisas do SIPD

[Pacote da Pesquisa PNADC](https://cran.r-project.org/package=PNADcIBGE)

[Pacote da Pesquisa PNAD COVID19](https://cran.r-project.org/package=COVIDIBGE)

[Pacote da Pesquisa PNS](https://cran.r-project.org/package=PNSIBGE)

[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/SIPDIBGE)](https://cran.r-project.org/package=SIPDIBGE) [![CRAN monthly downloads](https://cranlogs.r-pkg.org/badges/SIPDIBGE "CRAN monthly downloads")](https://cran.r-project.org/package=SIPDIBGE)
